(use eggdoc)

(define doc
  '((eggdoc:begin
     (name "sqlite3")
     (description (p "Bindings to version 3.x of the SQLite API."))
     (author (url "http://www.chust.org/" "Thomas Chust"))
     (usage)
     (download "sqlite3.egg")
     (requires "synch" "tinyclos" "easyffi" "miscmacros")

     (documentation
      (p "The API of SQLite changed significantly from version 2.x to 3.x. These are new bindings to the modified API, which are reasonably complete -- most procedures that take callback arguments are missing, though.")
      (p "For in-depth information on the functionality of the routines and general information you should consult the " (url "http://www.sqlite.org/" "SQLite documentation") " as well as this manual.")

      (subsection
       "Exceptions"
       (p "Unless otherwise indicated, all procedures and methods in this egg may throw an exception of the kind " (tt "(exn sqlite3)") " if something goes wrong. This exception will contain a " (tt "status") " property indicating the return value of the operation that failed:"
        (table
         (tr (th "Symbol") (th "Meaning"))
         #;(tr (td (tt "ok")) (td "Successful result"))
         (tr (td (tt "error")) (td "SQL error or missing database "))
         (tr (td (tt "internal")) (td "An internal logic error in SQLite "))
         (tr (td (tt "permission")) (td "Access permission denied "))
         (tr (td (tt "abort")) (td "Callback routine requested an abort "))
         (tr (td (tt "busy")) (td "The database file is locked "))
         (tr (td (tt "locked")) (td "A table in the database is locked "))
         (tr (td (tt "no-memory")) (td "A malloc() failed "))
         (tr (td (tt "read-only")) (td "Attempt to write a readonly database "))
         (tr (td (tt "interrupt")) (td "Operation terminated by sqlite-interrupt() "))
         (tr (td (tt "io-error")) (td "Some kind of disk I/O error occurred "))
         (tr (td (tt "corrupt")) (td "The database disk image is malformed "))
         (tr (td (tt "not-found")) (td "(Internal Only) Table or record not found "))
         (tr (td (tt "full")) (td "Insertion failed because database is full "))
         (tr (td (tt "cant-open")) (td "Unable to open the database file "))
         (tr (td (tt "protocol")) (td "Database lock protocol error "))
         (tr (td (tt "empty")) (td "(Internal Only) Database table is empty "))
         (tr (td (tt "schema")) (td "The database schema changed "))
         (tr (td (tt "too-big")) (td "Too much data for one row of a table "))
         (tr (td (tt "constraint")) (td "Abort due to contraint violation "))
         (tr (td (tt "mismatch")) (td "Data type mismatch "))
         (tr (td (tt "misuse")) (td "Library used incorrectly "))
         (tr (td (tt "no-lfs")) (td "Uses OS features not supported on host "))
         (tr (td (tt "authorization")) (td " Authorization denied"))
         #;(tr (td (tt "row")) (td (tt "sqlite3:step!") " has another row ready "))
         (tr (td (tt "done")) (td (tt "sqlite3:step!") " has finished executing, so no further data is ready")))))

      (subsection
       "Classes"
       (group
	(definition
	  (signatures
	   (signature "class" "<sqlite3:database>")
	   (signature "class" "<sqlite3:statement>"))
	  (p "These classes are derived from " (tt "<c++-object>") ". They hold a pointer to the underlying C-structure in their " (tt "this") " slot.")
	  (p (tt "<sqlite3:statement>") " also has a " (tt "database") " slot pointing to the database object it belongs to."))))

      (subsection
       "Managing databases"
       (group
	(procedure
	 "(sqlite3:open (path <string>)) => <sqlite3:database>"
	 (p "Opens the indicated database file and returns a " (tt "<sqlite3:database>") " object for it.")
	 (p "The given path is subject to the same special expansion as paths passed to " (p "open-input-file") " and similar procedures."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:define-collation (db <sqlite3:database>) (name <string>)) => <void>")
	   (signature "method" "(sqlite3:define-collation (db <sqlite3:database>) (name <string>) (proc <procedure-class>)) => <void>"))
	  (p "If " (tt "proc") " is given, registers a new collation sequence identified by " (tt "name") " for use in the context of database handle " (tt "db") ". If no procedure is passed, the collation sequence with the given name is removed.")
	  (p (tt "proc") " should have the signature " (tt "(proc (a <string>) (b <string>)) => <exact>") ". It should return a negative number if " (tt "a") " sorts before " (tt "b") ", a positive number if " (tt "b") " sorts before " (tt "a") " and zero if " (tt "a") " and " (tt "b") " are equal.")
	  (p "As " (tt "proc") " will be called in a callback context from within " (tt "sqlite3:step!") ", safety measures are installed to avoid throwing any exceptions, invoking continuations or returning invalid values from it. Attempts to do so will result in a " (tt "0") " return value and warning messages."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:define-function (db <sqlite3:database>) (name <string>) (n <exact>) (proc <procedure-class>)) => <void>")
	   (signature "method" "(sqlite3:define-function (db <sqlite3:database>) (name <string>) (n <exact>) (step-proc <procedure-class>) (seed <top>) #!optional ((final-proc <procedure-class>) identity)) => <void>"))
	  (p "If " (tt "proc") " is given, registers a new SQL function identified by " (tt "name") " for use in the context of database handle " (tt "db") ". If " (tt "step-proc") " and " (tt "final-proc") " are given, the new function becomes an aggregate function. Once registered, functions cannot be deleted.")
	  (p (tt "n") " is the number of parameters the new SQL function takes or " (tt "-1") " to allow any number of arguments.")
	  (p (tt "proc") " should have the signature " (tt "(proc . params) => <top>") ". It is called with the " (tt "n") " parameters given to the SQL function converted into Scheme objects like by " (tt "sqlite3:column-data") ". The return value is converted into an SQLite3 data object like by " (tt "sqlite3:bind!") ". A return value of " (tt "(void)") " corresponds to " (tt "NULL") " in SQLite3.")
	  (p (tt "step-proc") " should have the signature " (tt "(step-proc (seed <top>) . params) => <top>") ". It is called with the parameters given to the SQL function for every row being processed. The seed value passed is initially the one given as an argument to " (tt "sqlite3:define-function") "; for subsequent calls it is the last value returned by " (tt "step-proc") " and after completion of " (tt "final-proc") " it will be the initial value again.")
	  (p (tt "final-proc") " should have the signature " (tt "(final-proc (seed <top>)) => <top>") " and transforms the last seed value into the value to be returned from the aggregate function.")
	  (p "As " (tt "proc") ", " (tt "step-proc") " and " (tt "final-proc") " will be called in a callback context from within " (tt "sqlite3:step!") ", safety measures are installed to avoid throwing any exceptions, invoking continuations or returning invalid values from them. Attempts to do such things will result in " (tt "NULL") " return values and warning messages."))
	(procedure
	 "(sqlite3:set-busy-timeout! (db <sqlite3:database>) #!optional ((ms <exact>) 0)) => <void>"
	 (p "Installs a busy handler that waits at least the specified amount of milliseconds for locks on the given database. If " (tt "(<= ms 0)") " though, all busy handlers for the database are uninstalled."))
	(procedure
	 "(sqlite3:interrupt! (db <sqlite3:database>)) => <void>"
	 (p "Cancels any running database operation as soon as possible.")
	 (p "This function is always successful and never throws an exception."))
	(procedure
	 "(sqlite3:auto-committing? (db <sqlite3:database>)) => <bool>"
	 (p "Checks whether the database is currently in auto committing mode, i.e. no transaction is currently active.")
	 (p "This function always returns a state and never throws an exception."))
	(procedure
	 "(sqlite3:changes (db <sqlite3:database>) #!optional ((total <bool>) #f)) => <number>"
	 (p "Returns the number of rows changed by the last statement (if " (tt "(not total)") ") or since the database was opened (if " (tt "total") ").")
	 (p "This function always returns a count and never throws an exception."))
	(procedure
	 "(sqlite3:last-insert-rowid (db <sqlite3:database>)) => <number>"
	 (p "Returns the row ID of the last row inserted in " (tt "db") ".")
	 (p "This function always returns a number and never throws an exception."))
	(method
	 "(sqlite3:finalize! (db <sqlite3:database>)) => <void>"
	 (p "Closes the given database."))))

      (subsection
       "Managing statements"
       (group
	(procedure
	 "(sqlite3:prepare (db <sqlite3:database>) (sql <string>)) => <sqlite3:statement>, <string>"
	 (p "Compiles the first SQL statement in " (tt "sql") " and returns a " (tt "<sqlite3:statement>") " and the rest of " (tt "sql") ", which was not compiled (or an empty string)."))
	(procedure
	 "(sqlite3:repair! (stmt <sqlite3:statement>)) => <void>"
	 (p "Recompiles the SQL statement used to create " (tt "stmt") ", transfers all existing bindings from the old statement handle to the new one and destructively modifies " (tt "stmt") " to point to the new statement handle.")
	 (p "If the operation is successful, the old handle is finalized, in case of error, the new handle is finalized and the old one stays untouched.")
	 (p "Usually you should not have to call this routine by hand. It is invoked by " (tt "sqlite3:step!") " to automagically repair a stale statement handle after a database schema change."))
	(procedure
	 "(sqlite3:column-count (stmt <sqlite3:statement>)) => <exact>"
	 (p "Can be applied to any statement and returns the number of columns it will return as results.")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:column-name (stmt <sqlite3:statement>) (i <exact>)) => <string>"
	 (p "Can be applied to any statement and returns the name of the column number " (tt "i") " (counting from 0) as a string or " (tt "#f") " if the column has no name.")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:column-declared-type (stmt <sqlite3:statement>) (i <exact>)) => <string>"
	 (p "Can be applied to any statement and returns the declared type (as given in the " (tt "CREATE") " statement) of the column number " (tt "i") " (counting from 0) as a string or " (tt "#f") " if the column has no declared type.")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:bind-parameter-count (stmt <sqlite3:statement>)) => <exact>"
	 (p "Can be applied to any statement and returns the number of free parameters that can be bound in the statement.")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:bind-parameter-index (stmt <sqlite3:statement>) (name <string>)) => <exact>"
	 (p "Can be applied to any statement and returns the index of the bindable parameter called " (tt "name") " or " (tt "#f") " if no such parameter exists.")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:bind-parameter-name (stmt <sqlite3:statement>) (i <exact>)) => <string>"
	 (p "Can be applied to any statement and returns the name of the bindable parameter number " (tt "i") " (counting from 0) or " (tt "#f") " if no such parameter exists or the parameter has no name.")
	 (p "This procedure always succeeds and never throws an exception."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:bind! (stmt <sqlite3:statement>) (i <exact>)) => <void>")
	   (signature "method" "(sqlite3:bind! (stmt <sqlite3:statement>) (i <exact>) (v <void>)) => <void>")
	   (signature "method" "(sqlite3:bind! (stmt <sqlite3:statement>) (i <exact>) (v <exact>)) => <void>")
	   (signature "method" "(sqlite3:bind! (stmt <sqlite3:statement>) (i <exact>) (v <number>)) => <void>")
	   (signature "method" "(sqlite3:bind! (stmt <sqlite3:statement>) (i <exact>) (v <string>)) => <void>")
	   (signature "method" "(sqlite3:bind! (stmt <sqlite3:statement>) (i <exact>) (v <blob>)) => <void>"))
	  (p "Can be applied to any statement to bind its free parameter number " (tt "i") " (counting from 0) to the given value. Scheme types of the value map to SQLite types as follows:"
	     (table
	      (tr (th "Scheme type") (th "SQLite type"))
	      (tr (td "none") (td (tt "null")))
	      (tr (td (tt "<sqlite3:null-value>")) (td (tt "null")))
	      (tr (td (tt "<exact>")) (td (tt "integer")))
	      (tr (td (tt "<number>")) (td (tt "float")))
	      (tr (td (tt "<string>")) (td (tt "text")))
	      (tr (td (tt "<blob>")) (td (tt "blob")))))
	  (p "Unless there is internal trouble in SQLite3, this method should always succeeds and never throw an exception. For invalid parameter indices the method just silently does nothing."))
        (procedure
         "(sqlite3:bind-parameters! (stmt <sqlite3:statement>) . params) => <void>"
         (p "Binds the statement's free parameters."))
	(procedure
	 "(sqlite3:step! (stmt <sqlite3:statement>)) => <boolean>"
	 (p "Single-steps the execution of " (tt "stmt") " and returns " (tt "#t") " if a result row was produced, " (tt "#f") " if no further results are available as the statement has been stepped through. This procedure must be called at least once before any results can be retrieved from the statement."))
	(procedure
	 "(sqlite3:column-type (stmt <sqlite3:statement>) (i <exact>)) => <symbol>"
	 (p "Can be applied to a statement that has just been stepped (otherwise it returns " (tt "#f") ") and returns the SQLite type of the result column number " (tt "i") " (counting from 0) as a symbol.")
	 (p "The return value can be one of the symbols " (tt "null") ", " (tt "integer") ", " (tt "float") ", " (tt "text") " or " (tt "blob") ".")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:column-data (stmt <sqlite3:statement>) (i <exact>)) => <void | exact | number | string | blob>"
	 (p "Can be applied to a statement that has just been stepped. Consults " (tt "sqlite3:column-type") " to determine the type of the indicated column and to return its data as an appropriate scheme object.")
	 (p "See " (tt "sqlite3:bind!") " for the mapping between Scheme and SQLite data types. Columns of type " (tt "null") " are returned as " (tt "<sqlite3:null-value>") ". Also keep in mind that CHICKEN's " (tt "<exact>") " datatype can only hold a subset of the values an SQLite " (tt "integer") " can store. Large integer values may therefore be returned as floating point numbers from the database, but they will still be of class " (tt "<integer>") ".")
	 (p "This procedure always succeeds and never throws an exception."))
	(procedure
	 "(sqlite3:reset! (stmt <sqlite3:statement>)) => <void>"
	 (p "Can be applied to any statement and resets it such that execution using " (tt "sqlite3:step!") " will perform all operations of the statement again."))
	(method
	 "(sqlite3:finalize! (stmt <sqlite3:statement>)) => <void>"
	 (p "Must be applied to every statement to free its resources and discard it.")
	 (p (tt "sqlite3:close") " will not be able to close a database that has associated unfinalized statements."))))

      (subsection
       "Simple statement interface"
       (group
	(procedure
	 "(sqlite3:call-with-temporary-statements (proc <procedure-class>) (db <sqlite3:database>) . sqls) => <top>"
	 (p "Compiles the SQL sources in " (tt "sqls") " into statements in the context of " (tt "db") ", applies " (tt "proc") " to these statements and returns " (tt "proc") "'s result. The statements are created and finalized in " (tt "dynamic-wind") " entry and exit blocks around the application of " (tt "proc") "."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:exec (stmt <sqlite3:statement>) . params) => <void>")
	   (signature "method" "(sqlite3:exec (db <sqlite3:database>) (sql <string>) . params) => <void>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and executes the statement ignoring possible results from it."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:update (stmt <sqlite3:statement>) . params) => <exact>")
	   (signature "method" "(sqlite3:update (db <sqlite3:database>) (sql <string>) . params) => <exact>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and executes the specified statement ignoring possible results from it, returning the result of applying " (tt "sqlite3:changes") " to the affected database after the execution of the statement instead."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:first-result (stmt <sqlite3:statement>) . params) => <void | exact | number | string | blob>")
	   (signature "method" "(sqlite3:first-result (db <sqlite3:database>) (sql <string>) . params) => <void | exact | number | string | blob>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and single-steps the statement once returning the value of the first column in the first result row. Resets the statement again just before returning.")
	  (p "If the given statement does not yield any results, an " (tt "(exn sqlite3)") " is thrown with the " (tt "status") "-property set to " (tt "done") "."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:first-row (stmt <sqlite3:statement>) . params) => <list>")
	   (signature "method" "(sqlite3:first-row (db <sqlite3:database>) (sql <string>) . params) => <list>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and single-steps the statement once returning all columns in the first result row as a list.")
	  (p "If the given statement does not yield any results, an " (tt "(exn sqlite3)") " is thrown with the " (tt "status") "-property set to " (tt "done") "."))(definition
	  (signatures
	   (signature "method" "(sqlite3:fold-row (proc <procedure-class>) (stmt <sqlite3:statement>) initial . params) => <list>")
	   (signature "method" "(sqlite3:fold-row (proc <procedure-class>) (db <sqlite3:database>) (sql <string>) initial . params) => <list>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and executes it step by step. After each step, the column values of the current result row are retrieved and " (tt "proc") " is applied to the current folded value and the column values. The result of the application becomes the new folded value."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:for-each-row (proc <procedure-class>) (stmt <sqlite3:statement>) . params) => <void>")
	   (signature "method" "(sqlite3:for-each-row (proc <procedure-class>) (db <sqlite3:database>) (sql <string>) . params) => <void>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and executes it step by step. After each step, the column values of the current result row are retrieved and " (tt "proc") " is applied to them. The results of this application are discarded."))
	(definition
	  (signatures
	   (signature "method" "(sqlite3:map-row (proc <procedure-class>) (stmt <sqlite3:statement>) . params) => <list>")
	   (signature "method" "(sqlite3:map-row (proc <procedure-class>) (db <sqlite3:database>) (sql <string>) . params) => <list>"))
	  (p "(Compiles the given SQL), resets the statement, binds the statement's free parameters and executes it step by step. After each step, the column values of the current result row are retrieved and " (tt "proc") " is applied to them. The results of these applications are collected into a list."))))

      (subsection
       "Utility functions"
       (group
	(procedure
	 "(sqlite3:with-transaction (db <sqlite3:database>) (thunk <procedure-class>) #!optional ((type <symbol>) 'deferred)) => <void>"
	 (p "Runs " (tt "thunk") " within the scope of a transaction on the dataase " (tt "db") ".")
	 (p "The transaction is committed upon exit from " (tt "thunk") " if " (tt "thunk") " returns a true value. If " (tt "thunk") " returns a false value or throws an exception, the transaction is rolled back.")
	 (p "The " (tt "type") " of the transaction can be specified as one of the symbols " (tt "deferred") ", " (tt "immediate") " or " (tt "exclusive") "."))
	(procedure
	 "(sqlite3:complete? (sql <string>)) => <boolean>"
	 (p "Checks whether " (tt "sql") " comprises at least one complete SQL statement."))
	(procedure
	 "(sqlite3:library-version) => <string>"
	 (p "Returns a string identifying the version of SQLite in use."))
	(procedure
	 "(sqlite3:null-value? <object>) => <boolean>"
	 (p "Is the " (tt "<object>") " a <sqlite3:null-value>?")
	 (p "The <sqlite3:null-value> is compatible with the \"sql-null\" egg. "
	    "The default \"sql-null\" egg function " (code "(sql-null)") " "
	    "= the <sqlite3:null-value>. "
	    "But to ensure equality - " (code "(define sql-null sqlite3:null)") ".")))))

     (history
      (version "2.0.4" "Added " (code "sqlite3:fold-row") " & " (code "sqlite3:bind-parameters!") ". Fix for introduced bug in " (code "sqlite3:changes") ". [Kon Lovett]")
      (version "2.0.3" "Added " (code "sqlite3:null-value") ", " (code "sqlite3:null-value?") ", and " (code "sqlite3:null") ". [Kon Lovett]")
      (version "2.0.2" "Use of extended " (tt "define-foreign-enum") ". Removed deprecated " (tt "pointer") " use. [Kon Lovett]")
      (version "2.0.1" "Deprecated " (tt "<byte-vector>") ", use " (tt "<blob>") " [Kon Lovett]")
      (version "2.0.0" "Now using " (tt "(void)") " to represent " (tt "NULL"))
      (version "1.5.9" "dll extension not used anymore in newer chickens [felix]")
      (version "1.5.8" "Update for synch 1.3 [Kon Lovett]")
      (version "1.5.7" "Updated compiler flags to pull in tinyclos and easyffi")
      (version "1.5.6" "Replaced deprecated synch operations [Kon Lovett]")
      (version "1.5.5" "Correction in the documentation, added sqlite3:with-transaction")
      (version "1.5.4" "Typo fixed thanks to the new imports checking code")
      (version "1.5.3" "Proper multithreading locks for the callback code")
      (version "1.5.2" "Code cleanups")
      (version "1.5.1" "Potential memory leaks removed")
      (version "1.5.0" "Support for user defined collation sequences and functions has been added")
      (version "1.4.0" "Stale statement handles due to schema changes are now automagically recompiled to keep them valid")
      (version "1.3.1" "Several small routines added")
      (version "1.3.0" "Special hacks removed as CVS version of SQLite3.3.4 has been fixed")
      (version "1.2.0" "Special hacks to deal with \"valid\" " (tt "NULL") " statements")
      (version "1.1.4" "Tightened security measures against " (tt "#f") " pointers")
      (version "1.1.3" "Integers not fitting in a fixnum are now read correctly from the database [thanks to Zbigniew]")
      (version "1.1.2" "Setup file patched to call compiled output .dll on Windows")
      (version "1.1.1" "All procedures now reset prepared statements where you would do that by hand anyway")
      (version "1.1.0" "Promoted " (tt "sqlite3:call-with-temporary-statement") " to " (tt "sqlite3:call-with-temporary-statements") " and fixed a really stupid coding mistake in " (tt "sqlite3:changes"))
      (version "1.0.3" "Fixed C compiler warnings")
      (version "1.0.2" "Added a typecheck for increased safety")
      (version "1.0.1" "Fixed type mistakes in the source")
      (version "1.0.0" "Initial release"))

      (license
       "Copyright (c) 2005, Thomas Chust <chust@web.de>.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer. Redistributions in
  binary form must reproduce the above copyright notice, this list of
  conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution. Neither the name of the
  author nor the names of its contributors may be used to endorse or
  promote products derived from this software without specific prior
  written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS
IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."))))

(eggdoc->html
 doc
 (append
  (eggdoc:make-stylesheet doc)
  `((method *macro* . ,eggdoc:make-defsig))))
